Title: Data Sets for Diagnostic Classification Modeling
Version: 0.2.0
Description: Access data sets for demonstrating or testing diagnostic classification models. Simulated data sets can be used to compare estimated model output to true data-generating values. Real data sets can be used to demonstrate real-world applications of diagnostic models.
License: MIT + file LICENSE
URL: https://dcmdata.r-dcm.org, https://github.com/r-dcm/dcmdata
BugReports: https://github.com/r-dcm/dcmdata/issues
Depends: R (≥ 3.5)
Imports: cli, rlang (≥ 1.1.0), tibble
Config/testthat/edition: 3
Config/Needs/website: r-dcm/rdcmtemplate
Config/Needs/documentation: openpharma/roxylint
Config/roxylint: list(linters = roxylint::tidy)
Encoding: UTF-8
Language: en-US
LazyData: true
RoxygenNote: 7.3.3
Suggests: spelling, testthat (≥ 3.0.0)
NeedsCompilation: no
Packaged: 2026-03-10 18:59:14 UTC; jakethompson
Author: W. Jake Thompson ORCID iD [aut, cre], University of Kansas [cph], Institute of Education Sciences [fnd]
Maintainer: W. Jake Thompson <wjakethompson@gmail.com>
Repository: CRAN
Date/Publication: 2026-03-10 19:20:02 UTC

dcmdata: Data Sets for Diagnostic Classification Modeling

Description

logo

Access data sets for demonstrating or testing diagnostic classification models. Simulated data sets can be used to compare estimated model output to true data-generating values. Real data sets can be used to demonstrate real-world applications of diagnostic models.

Author(s)

Maintainer: W. Jake Thompson wjakethompson@gmail.com (ORCID)

Other contributors:

See Also

Useful links:


Diagnosing teachers' multiplicative reasoning (DTMR)

Description

This is a simulated data set modeled after the DTMR study described by Bradshaw et al. (2014) and Izsák et al. (2019). The data was simulated from the loglinear cognitive diagnostic model (LCDM), which is the model that was used to analyze the data in the referenced articles. The data set consists of 990 responses to the 27 items included in the final version of the DTMR data, matching the sample that was collected by the original authors. Each respondent was randomly assigned a mastery profile using the profile proportions reported in Figure 10 of Izsák et al. (2019). Item responses were then generated for each respondent using their assigned mastery profile and the item parameters reported in Table 1 of Bradshaw et al. (2014). Reproducible code for generating the simulated data is available in the GitHub repository for this package.

Usage

dtmr_data

dtmr_qmatrix

dtmr_true_structural

dtmr_true_profiles

dtmr_true_items

Format

dtmr_data is a tibble containing simulated DTMR response data with 990 rows and 28 variables.

dtmr_qmatrix is a tibble that identifies which skills are measured by each DTMR item, as reported in Bradshaw et al. (2014). The DTMR assessment contains 27 items measuring 4 skills. The dtmr_qmatrix correspondingly is made up of 27 rows and 5 variables.

Simulation values

In addition to the simulated data sets, the true values used to simulate the data are included for reference. This may be useful if, for example, you want to estimate a model and then check how well the estimated parameters match values that were used to create the data.

To simulate the data, we first need dtmr_true_structural. This is a tibble that contains the structural parameters reported in Figure 10 of Izsák et al. (2019). The structural parameters define the probability of observing each possible profile in the population of respondents. Each row represents one possible mastery profile. Therefore, there are 16 rows and 5 variables.

Using the dtmr_true_structural values, we randomly sampled a mastery profile for each of the 990 respondents. The true profiles for each respondent are available in dtmr_true_profiles. There are a total of 990 rows and 5 variables.

We use the dtmr_true_profiles and the dtmr_qmatrix to identify whether each respondent possess the attributes required by each item. Based on which attributes are required and possessed, we use the dtmr_true_items to calculate the log odds of each respondent providing a correct response to each item. dtmr_true_items contains the estimated item parameters reported in Table 1 of Bradshaw et al. (2014). This a tibble with 27 rows and 7 columns.

Finally, we convert the log odds values to probabilities and draw a random Bernoulli variable using the probabilities of a correct response. The drawn Bernoulli values are the simulated item scores that make up the dtmr_data.

Details

The skills correspond to knowledge of:

  1. Referent units

  2. Partitioning and iterating

  3. Appropriateness

  4. Multiplicative comparisons

References

Bradshaw, L., Izsák, A., Templin, J., & Jacobson, E. (2014). Diagnosing teachers' understandings of rational numbers: Building a multidimensional test within the diagnostic classification framework. Educational Measurement: Issues and Practice, 33(1), 2-14. doi:10.1111/emip.12020

Izsák, A., Jacobson, E., & Bradshaw, L. (2019). Surveying middle-grades teachers' reasoning about fraction arithmetic in terms of measured quantities. Journal for Research in Mathematics Education, 50(2), 156-209. doi:10.5951/jresematheduc.50.2.0156


Examination for the certificate of proficiency in English (ECPE)

Description

This is data from the grammar section of the ECPE, administered annually by the English Language Institute at the University of Michigan. This data contains responses to 28 questions from 2,922 respondents, which ask respondents to complete a sentence with the correct word. This data set has been used by Templin & Hoffman (2013) and Templin & Bradshaw (2014) for demonstrating the log-linear cognitive diagnosis model (LCDM) and the hierarchical diagnostic classification model (HDCM), respectively.

Usage

ecpe_data

ecpe_qmatrix

Format

ecpe_data is a tibble containing ECPE response data with 2,922 rows and 29 variables.

ecpe_qmatrix is a tibble that identifies which skills are measured by each ECPE item. This section of the ECPE contains 28 items measuring 3 skills. The ecpe_qmatrix correspondingly is made up of 28 rows and 4 variables.

Details

The skills correspond to knowledge of:

  1. Morphosyntactic rules

  2. Cohesive rules

  3. Lexical rules

For more details, see Buck & Tatsuoka (1998) and Henson & Templin (2007).

References

Buck, G., & Tatsuoka, K. K. (1998). Application of the rule-space procedure to language testing: Examining attributes of a free response listening test. Language Testing, 15(2), 119-157. doi:10.1177/026553229801500201

Henson, R., & Templin, J. (2007, April). Large-scale language assessment using cognitive diagnosis models. Paper presented at the Annual meeting of the National Council on Measurement in Education, Chicago, IL.

Templin, J., & Hoffman, L. (2013). Obtaining diagnostic classification model estimates using Mplus. Educational Measurement: Issues and Practice, 32(2), 37-50. doi:10.1111/emip.12010

Templin, J., & Bradshaw, L. (2014). Hierarchical diagnostic classification models: A family of models for estimating and testing attribute hierarchies. Psychometrika, 79(2), 317-339. doi:10.1007/s11336-013-9362-0


Tatsuoka fraction subtraction data

Description

The fraction subtraction data was originally described by Tatsuoka (1990) to introduce the rule space model, and later by Tatsuoka (2002) demonstrate the use of cognitive modeling in educational testing. The data contains responses from 536 respondents to 20 items which ask about different skills related to the subtraction of fractions. The data set was uploaded to the Item Response Warehouse (Domingue et al., 2025) and is reformatted here.

Usage

fraction_data

fraction_qmatrix

Format

fraction_data is a tibble containing response data with 536 rows and 21 variables:

fraction_qmatrix is a tibble that identifies which skills are measured by each item. This assessment contains 20 items measuring 8 skills. The fraction_qmatrix correspondingly is made up of 20 rows and 9 variables.

Details

The skills correspond to knowledge of:

References

Domingue, B., Braginsky, M., Caffrey-Maffei, L., Gilbert, J. B., Kanopka, K., Kapoor, R., Lee, H., Liu, Y., Nadela, S., Pan, G., Zhang, L., Zhang, S., & Frank, M. C. (2025). An introduction to the Item Response Warehouse (IRW): A resource for enhancing data usage in psychometrics. Behavior Research Methods, 57, Article 276. doi:10.3758/s13428-025-02796-y

Tatsuoka, C. (2002). Data analytic methods for latent partially ordered classification models. Journal of the Royal Statistical Society: Series C (Applied Statistics), 51(3), 337-350. doi:10.1111/1467-9876.00272

Tatsuoka, K. K. (1990). Toward an integration of item-response theory and cognitive error diagnosis. In N. Frederiksen, R. Glaser, A. Lesgold, & M. G. Shafto (Eds.), Diagnosing monitoring of skill and knowledge acquisition (pp. 453-488). Lawrence Erlbaum Associates.


Generate unique identifiers

Description

Create unique alphanumeric identifiers with a specified character length and proportions of alpha and numeric characters.

Usage

generate_ids(n, characters, prop_numeric = 1, n_attempt = n * 3)

Arguments

n

The number of unique identifiers to generate.

characters

The number of characters to be included in each identifier.

prop_numeric

The proportion of characters that should be numeric. The default is 1 (i.e., all numbers). If less than 1, identifiers will also include lowercase and uppercase letters.

n_attempt

The number of allowed attempts for generating the requested number of identifiers. See details for more information.

Details

When identifiers are long (e.g., characters >= 10), it is slow and computationally intensive to find all possible permutations of the specified number of alpha and numeric characters. Therefore, identifiers are generated one at a time by sampling the required number of characters. This greatly increases efficiency, as we don't waste time generating multiple millions of identifiers when we might only need a few hundred. However, this means that it is possible we could generate duplicate identifiers. The n_attempt argument allows us to control how many identifiers we can generate in order to achieve our desired n unique identifiers. If we fail to find n unique identifiers after n_attempt, the function will error. For example, consider a request for 1,000 identifiers, each with 2 characters and only using numbers. With the number 0-9, there are only 100 possible two-character permutations. Thus, after n_attempt, the function will fail as 1,000 unique identifiers cannot be found.

Value

A factor vector of length n.

Examples

generate_ids(n = 10, characters = 5)
generate_ids(n = 100, characters = 10, prop_numeric = 0.5)

Log-odds transformation

Description

These functions implement the log-odds (or logit) transformation. This is a common transformation for psychometric models that is used to put probabilities on a continuous scale.

Usage

logit(x)

inv_logit(x)

Arguments

x

A number to be transformed.

Value

A transformed double.

Examples

logit(0.6)
logit(0.5)

inv_logit(3.5)
inv_logit(0)


Millon Clinical Multiaxial Inventory-III (MCMI-III)

Description

The MCMI-III data were originally collected by Rossi et al. (2010) and contain responses to 44 items from the Dutch version of the MCMI-III. The data has also been used by de la Torre et al. (2018) and Van der Ark et al. (2019) to demonstrate the applicability of diagnostic classification models in psychological assessment. The data set was uploaded to the Item Response Warehouse (Domingue et al., 2025) and is reformatted here.

Usage

mcmi_data

mcmi_qmatrix

Format

mcmi_data is a tibble containing response data with 1,208 rows and 45 variables:

mcmi_qmatrix is a tibble that identifies which disorders are measured by each item. This assessment contains 44 items measuring 3 disorders. The mcmi_qmatrix correspondingly is made up of 44 rows and 4 variables.

Details

The attributes correspond to the presence of:

References

de la Torre, J., Van der Ark, L. A., & Rossi, G. (2018). Analysis of clinical data from cognitive diagnosis modeling framework. Measurement and Evaluation in Counseling and Development, 51(4), 281-296. doi:10.1080/07481756.2017.1327286

Domingue, B., Braginsky, M., Caffrey-Maffei, L., Gilbert, J. B., Kanopka, K., Kapoor, R., Lee, H., Liu, Y., Nadela, S., Pan, G., Zhang, L., Zhang, S., & Frank, M. C. (2025). An introduction to the Item Response Warehouse (IRW): A resource for enhancing data usage in psychometrics. Behavior Research Methods, 57, Article 276. doi:10.3758/s13428-025-02796-y

Rossi, G., Elklit, A., & Simonsen, E. (2010). Empirical evidence for a four factor framework of personality disorder organization: Multigroup confirmatory factor analysis of the Millon Clinical Multiaxial Inventory-III personality disorder scales across Belgian and Danish data samples. Journal of Personality Disorders, 24(1), 128-150. doi:10.1521/pedi.2010.24.1.128

Van der Ark, L. A., Rossi, G., & Sijtsma, K. (2019). Nonparametric item response theory and Mokken scale analysis, with relations to latent class models and cognitive diagnostic models. In M. von Davier & Y.-S. Lee (Eds.), Handbook of diagnostic classification models (pp. 21-45). Springer. doi:10.1007/978-3-030-05584-4_2


MacReady & Dayton multiplication data (MDM)

Description

This is a small data set of multiplication item responses. This data contains responses to 4 items from 142 respondents, which ask respondents to complete an integer multiplication problem.

Usage

mdm_data

mdm_qmatrix

Format

mdm_data is a tibble containing responses to multiplication items, as described in MacReady and Dayton (1977). There are 142 rows and 5 variables.

mdm_qmatrix is a tibble that identifies which skills are measured by each MDM item. This MDM data contains 4 items, all of which measure the skill of multiplication. The mdm_qmatrix correspondingly is made up of 4 rows and 2 variables.

References

MacReady, G. B., & Dayton, C. M. (1977). The use of probabilistic models in the assessment of mastery. Journal of Educational Statistics, 2(2), 99-120. doi:10.2307/1164802


Pathways for instructionally embedded assessment (PIE)

Description

PIE was a proof-of-concept assessment partnership between Accessible Teaching, Learning, and Assessment Systems (ATLAS) at the University of Kansas and the Missouri Department of Elementary and Secondary Education (DESE). The goal of the PIE project was to demonstrate the utility of through-year instructionally embedded assessments for both informing instructional decisions and reporting summative results. A learning pathway was developed for each learning standard so that teachers could identify precisely where students are in their learning journey. There are two data sets containing student responses to a learning pathway aligned to the 5.RA.A.1b learning standard. The first data set includes responses from the Spring 2024 field test, and the second includes responses from the 2024–2025 pilot administration.

Usage

pie_ft_data

pie_ft_qmatrix

pie_pilot_data

pie_pilot_qmatrix

Format

pie_ft_data is a tibble containing PIE response data from the initial field test with 172 rows and 16 variables.

pie_ft_qmatrix is a tibble that identifies which levels of the learning pathway are measured by each PIE item. The PIE field test utilized 15 items to measure the 3 levels in the 5.RA.A.1b pathway. The pie_ft_qmatrix correspondingly is made up of 15 rows and 4 variables.

pie_pilot_data is a tibble containing PIE response data from the pilot administration with 2,370 rows and 19 variables.

pie_pilot_qmatrix is a tibble that identifies which levels of the learning pathway are measured by each PIE item. The PIE pilot utilized 17 items to measure the 3 levels in the 5.RA.A.1b pathway. The pie_pilot_qmatrix correspondingly is made up of 17 rows and 4 variables.

Details

Learning Pathway

The 5.RA.A.1b is a grade 5 mathematics standard in the Relationships and Algebraic Thinking (RA) domain. Specifically, this standard comes from Cluster A (Represent and analyze patterns and relationships), and represents Expectation 1 (Investigate the relationship between two numeric patterns), sub-expectation B (Translate two numeric patterns into two sets of ordered pairs).

The learning pathway that was developed for 5.RA.A.1b includes three vertical levels that build toward the intended learning target. Level 1 (L1) includes emerging concepts and skills, Level 2 (L2) includes skills approaching the learning target, and Level 3 (L3) represents the learning target and is directly aligned to the learning standard. For this learning pathway, the levels are:

For additional information on the development of the learning pathways, see Kim et al. (2024).

Assessment Design

The PIE field test was administered as a fixed-form assessment during Spring 2024. During the field test, each student was assessed on all three levels within the learning pathway at a single point in time. Following the field test, the test development team reviewed item data and selected items for promotion to the pilot item pool. pie_ft_data includes only items that were promoted for use during the pilot administration. For more information on the PIE field test, see ATLAS (2025a).

During the pilot administration, teachers chose when to assess each of the learning standards. PIE assessments were intended to be administered at three points during the instructional cycle. The first assessment (baseline) was administered before the instructional cycle. The baseline assessment measured only Level 1 skills, allowing teachers to evaluate whether their students were ready for instruction on the standard. After some instruction had occurred, teachers administered the second assessment (midway). The midway assessment measured Level 2 skills for all students and additionally re-assessed Level 1 skills for students who did not demonstrate mastery of those skills on the baseline assessment. Teachers can then observe where their students are at, evaluate the progress they have made, and plan additional targeted instruction. The final assessment was administered at the end of the instructional unit (end_of_unit). This assessment included items measuring Level 3 skills for all students, as well as Level 2 skills for students who did not demonstrate mastery of those skills on the midway assessment. Teachers could again use this information to monitor their students' progress and make decisions about next instructional steps. In total, the three pathway levels were assessed over three timepoints. For additional information on the pilot design and administration, see ATLAS (2025b).

Notably, there is not a one-to-one correspondence between items included in the field test and pilot data sets. There are three items that were promoted following the field test, but were not administered during the pilot. These items were either held back in the event that other items included in the pilot pool had to be removed and replaced during the pilot administration, or were assigned to a fixed-form end-of-year assessment that is not included in this data. Additionally, there are five items that were administered during the pilot that were not directly field tested. These items are "twins" of other items that were field tested. For details on the item twinning approach, see ATLAS (2025a).

References

Accessible Teaching, Learning, and Assessment Systems. (2025a). PIE assessment design and development. University of Kansas. https://pie.atlas4learning.org/sites/default/files/documents/resources/PIE_Assessment_Design_Development_Technical_Report.pdf

Accessible Teaching, Learning, and Assessment Systems. (2025b). PIE pilot study: Design and administration evidence. University of Kansas. https://pie.atlas4learning.org/sites/default/files/documents/resources/PIE_Pilot_Study_Design_and_Administration_Evidence.pdf

Kim, E. M., Nash, B., & Swinburne Romine, R. (2024). Pathways for instructionally embedded assessment (PIE): Developing learning pathways for the PIE assessment system. University of Kansas; Accessible Teaching, Learning, and Assessment Systems. https://pie.atlas4learning.org/sites/default/files/documents/resources/Developing_Learning_Pathways_for_the_PIE_Assessment_System.pdf


Rapid online assessment of reading and phonological awareness (ROAR-PA)

Description

The ROAR-PA is an online assessment of phonological awareness, which is a target for early intervention in order to improve reading development. The ROAR-PA was developed, and data collected by, Gijbels et al. (2024), who identified a 3-factor structure that both represents specific skills within phonological awareness and is predictive of future reading development. The data set was uploaded to the Item Response Warehouse (Domingue et al., 2025) and is reformatted here.

Usage

roarpa_data

roarpa_qmatrix

Format

roarpa_data is a tibble containing response data with 272 rows and 58 variables:

roarpa_qmatrix is a tibble that identifies which ROAR-PA subtest is measured by each item. This data set contains 57 items measuring 3 attributes. The roarpa_qmatrix therefore has 57 rows and 4 variables:

Details

The ROAR-PA assessment consists of 5 subtests, three of which are included in this data set:

References

Domingue, B., Braginsky, M., Caffrey-Maffei, L., Gilbert, J. B., Kanopka, K., Kapoor, R., Lee, H., Liu, Y., Nadela, S., Pan, G., Zhang, L., Zhang, S., & Frank, M. C. (2025). An introduction to the Item Response Warehouse (IRW): A resource for enhancing data usage in psychometrics. Behavior Research Methods, 57, Article 276. doi:10.3758/s13428-025-02796-y

Gijbels, L., Burkhardt, A., Ma, W. A., & Yeatman, J. D. (2024). Rapid online assessment of reading and phonological awareness (ROAR-PA). Scientific Reports, 14, Article 10249. doi:10.1038/s41598-024-60834-9


Trends in international mathematics and science study (TIMSS) assessment for grade 8 mathematics (2003)

Description

This is data from the United States sample of the 2003 TIMSS assessment for grade 8 mathematics. This data contains responses to 23 items from 757 respondents. This data has been used by Skaggs et al. (2016) and Su et al. (2013) to evaluate the appropriateness of using diagnostic models for modeling the TIMSS assessment data. The data set was uploaded to the Item Response Warehouse (Domingue et al., 2025) and is reformatted here.

Usage

timss03_data

timss03_qmatrix

Format

timss03_data is a tibble containing TIMSS response data with 757 rows and 24 variables.

timss03_qmatrix is a tibble that identifies which skills are measured by each TIMSS 2003 item. This data set contains a subset of data consisting of 23 items measuring 13 skills. The timss03_qmatrix correspondingly is made up of 23 rows and 14 variables.

Details

The skills correspond to knowledge of:

For more details, see Table 2 of Su et al. (2013).

References

Domingue, B., Braginsky, M., Caffrey-Maffei, L., Gilbert, J. B., Kanopka, K., Kapoor, R., Lee, H., Liu, Y., Nadela, S., Pan, G., Zhang, L., Zhang, S., & Frank, M. C. (2025). An introduction to the Item Response Warehouse (IRW): A resource for enhancing data usage in psychometrics. Behavior Research Methods, 57, Article 276. doi:10.3758/s13428-025-02796-y

Skaggs, G., Wilkins, J. L. M., & Hein, S. F. (2016). Grain size and parameter recovery with TIMSS and the general diagnostic model. International Journal of Testing, 16(4), 310-330. doi:10.1080/15305058.2016.1145683

Su, Y.-L., Choi, K. M., Lee, W.-C., Choi, T., & McAninch, M. (2013). Hierarchical cognitive diagnostic analysis for TIMSS 2003 mathematics (Research Report No. 35). University of Iowa, Center for Advanced Studies in Measurement and Assessment. https://education.uiowa.edu/sites/education.uiowa.edu/files/2022-10/casma-research-report-35.pdf


Trends in international mathematics and science study (TIMSS) assessment for grade 4 mathematics (2007)

Description

This is data from the United States sample of the 2007 TIMSS assessment for grade 4 mathematics. This data contains responses to 25 items from 698 respondents and has been used previously by Lee et al. (2011) and Park et al. (2014, 2018) to estimate diagnostic classification models. The data set was uploaded to the Item Response Warehouse (Domingue et al., 2025) and is reformatted here.

Usage

timss07_data

timss07_skill_qmatrix

timss07_topic_qmatrix

timss07_domain_qmatrix

Format

timss07_data is a tibble containing TIMSS response data with 698 rows and 26 variables.

timss07_skill_qmatrix is a tibble that identifies which skills are measured by each TIMSS 2007 item. The timss07_skill_qmatrix is made up of 25 rows and 16 variables.

timss07_topic_qmatrix is a tibble that identifies which topics are measured by each TIMSS 2007 item. This form of the Q-matrix was used by Park et al. (2014, 2018), who combined the "Number Sentences with Whole Numbers" and "Patterns and Relationships" topics in the "Number" domain into a single attributes (n_nspr), as well as the "Reading and Interpreting" and "Organizing and Representing" topics in the "Data & Display" domain (dd_rior). Thus, timss07_topic_qmatrix is made up of 25 rows and 8 variables.

timss07_domain_qmatrix is a tibble that identifies which domains are measured by each TIMSS 2007 item. The timss07_domain_qmatrix is made up of 25 rows and 3 variables.

Details

The skills for the 2007 TIMSS are organized into domains and topics. Attribute names in Q-matrices are named by combining the hierarchical elements. For example, timss07_skill_qmatrix attributes names are ⁠{domain}_{topic}_{skill}⁠, whereas attributes in timss07_topic_qmatrix are named ⁠{domain}_{topic}⁠.

Domain Topic Skill
Number (n) Whole Numbers (wn) Representing, comparing, and ordering whole numbers as well as demonstrating knowledge of place value (represent)
Number (n) Whole Numbers (wn) Recognize multiples, computing with whole numbers using the four operations, and estimating computations (compute)
Number (n) Whole Numbers (wn) Solve problems, including those set in real life contexts (solve)
Number (n) Whole Numbers (wn) Solve problems involving proportions (proportions)
Number (n) Fractions and Decimals (fd) Recognize, represent, and understand fractions and decimals as parts of a whole and their equivalents (parts)
Number (n) Fractions and Decimals (fd) Solve problems involving simple fractions and decimals including their addition and subtraction (solve)
Number (n) Number Sentences with Whole Numbers (ns) Find the missing number or operation and model simple situations involving unknowns in number sentence or expressions (model)
Number (n) Patterns and Relationships (pr) Describe relationships in patterns and their extensions; generate pairs of whole numbers by a given rule and identify a rule for every relationship given pairs of whole numbers (describe)
Geometric Shapes & Measurement (gm) Lines and Angles (la) Measure, estimate, and understand properties of lines and angles and be able to draw them (properties)
Geometric Shapes & Measurement (gm) Two- and Three-dimensional Shapes (tt) Classify, compare, and recognize geometric figures and shapes and their relationships and elementary properties (figures)
Geometric Shapes & Measurement (gm) Two- and Three-dimensional Shapes (tt) Calculate and estimate perimeters, area, and volume (calculate)
Geometric Shapes & Measurement (gm) Location and Movement (lm) Locate points in an informal coordinate to recognize and draw figures and their movement (locate)
Data & Display (dd) Reading and Interpreting (ri) Read data from tables, pictographs, bar graphs, and pie charts (read)
Data & Display (dd) Reading and Interpreting (ri) Comparing and understanding how to use information from data (information)
Data & Display (dd) Organizing and Representing (or) Understanding different representations and organizing data using tables, pictographs, and bar graphs (data)

For more details, see Table 2 of Lee et al. (2011).

References

Domingue, B., Braginsky, M., Caffrey-Maffei, L., Gilbert, J. B., Kanopka, K., Kapoor, R., Lee, H., Liu, Y., Nadela, S., Pan, G., Zhang, L., Zhang, S., & Frank, M. C. (2025). An introduction to the Item Response Warehouse (IRW): A resource for enhancing data usage in psychometrics. Behavior Research Methods, 57, Article 276. doi:10.3758/s13428-025-02796-y

Lee, Y.-S., Park, Y. S., & Taylan, D. (2011). A cognitive diagnostic modeling of attribute mastery in Massachusetts, Minnesota, and the U.S. national sample using the TIMSS 2007. International Journal of Testing, 11(2), 144-177. doi:10.1080/15305058.2010.534571

Park, Y. S., & Lee, Y.-S. (2014). An extension of the DINA model using covariates: Examining factors affecting response probability and latent classification. Applied Psychological Measurement, 38(5), 376-390. doi:10.1177/0146621614523830

Park, Y. S., Xing, K., & Lee, Y.-S. (2018). Explanatory cognitive diagnostic models: Incorporating latent and observed predictors. Applied Psychological Measurement, 42(5), 376-392. doi:10.1177/0146621617738012